common

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AutoInitSessionService

type AutoInitSessionService struct {
	session.Service
}

AutoInitSessionService wraps a real service and ensures State is initialized. This fixes a regression in ADK v0.2.0 where InMemoryService creates sessions with nil state maps (see GitHub Issue #324).

func NewAutoInitService

func NewAutoInitService(s session.Service) *AutoInitSessionService

NewAutoInitService creates a new AutoInitSessionService wrapper.

func (*AutoInitSessionService) Create

Create intercepts session creation and ensures the state map is never nil.

Jump to