launcher

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 17, 2025 License: MIT Imports: 32 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunConsole

func RunConsole(ctx context.Context, cfg *ConsoleConfig) error

RunConsole runs the agent in console mode with agent-controlled flow

func RunSimpleWeb

func RunSimpleWeb(ctx context.Context, cfg *SimpleWebConfig) error

RunSimpleWeb runs a simplified chat-only web interface

func RunStudio added in v1.0.5

func RunStudio(port int) error

RunStudio starts the Studio web server

func RunWeb

func RunWeb(ctx context.Context, cfg *WebConfig) error

RunWeb runs the agent in web mode with ADK's embedded browser UI

Types

type ConsoleConfig

type ConsoleConfig struct {
	AgentConfig    *config.AgentConfig
	AppConfig      *config.AppConfig
	ProviderName   string
	ModelName      string
	SessionService session.Service
	DebugMode      bool
	Parameters     map[string]string
}

ConsoleConfig contains configuration for the console launcher

type SimpleWebConfig

type SimpleWebConfig struct {
	AgentConfig    *config.AgentConfig
	ProviderName   string
	ModelName      string
	SessionService session.Service
	Port           int
}

SimpleWebConfig contains configuration for the simple web launcher

type WebConfig

type WebConfig struct {
	AgentConfig    *config.AgentConfig
	ProviderName   string
	ModelName      string
	SessionService session.Service
	Port           int
}

WebConfig contains configuration for the web launcher

Jump to