web

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 9, 2025 License: MIT Imports: 2 Imported by: 0

README

React + Vite

This template provides a minimal setup to get React working in Vite with HMR and some ESLint rules.

Currently, two official plugins are available:

React Compiler

The React Compiler is not enabled on this template because of its impact on dev & build performances. To add it, see this documentation.

Expanding the ESLint configuration

If you are developing a production application, we recommend using TypeScript with type-aware lint rules enabled. Check out the TS template for information on how to integrate TypeScript and typescript-eslint in your project.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetDistFS

func GetDistFS() fs.FS

GetDistFS returns the embedded dist filesystem Returns nil if dist directory doesn't exist (not built)

Types

This section is empty.

Jump to